<?php
defined('ABSPATH') or die('No script kiddies please!!');
if (!class_exists('WOBD_Setup')) {

    class WOBD_Setup extends WOBD_Library {

        /**
         * Includes all the backend functionality
         *
         * @since 1.0.0
         */
        function __construct() {

            add_filter('gettext', array($this, 'wobd_change_publish_button'), 10, 2);
            add_action('admin_head-post.php', array($this, 'wobd_hide_publishing_actions'));
            add_action('admin_head-post-new.php', array($this, 'wobd_hide_publishing_actions'));
            add_action('add_meta_boxes', array($this, 'wobd_add_badges_setup')); //added blog showcase metabox
            add_action('add_meta_boxes', array($this, 'wobd_badge_preview')); //added blog showcase metabox
            add_action('add_meta_boxes', array($this, 'wobd_individual_badge_settings')); //added blog showcase metabox
            add_filter('post_row_actions', array($this, 'wobd_remove_row_actions'), 10, 1);
            add_filter('manage_wobd-badge-designer_posts_columns', array($this, 'wobd_columns_head'));
            add_action('manage_wobd-badge-designer_posts_custom_column', array($this, 'wobd_columns_content'), 10, 2);
            add_action('admin_post_wobd_settings_save', array($this, 'wobd_form_settings'));
            $wobd_common_settings = get_option('wobd_common_settings');
            if (isset($wobd_common_settings['wobd_page_configure_option']) && $wobd_common_settings['wobd_page_configure_option'] == 'method_one') {
                add_action('woocommerce_product_thumbnails', array($this, 'wobd_display_single_page_badges'), 20);
                add_filter('woocommerce_sale_flash', array($this, 'wobd_remove_sale_text'), 2, 2);
            } else if (isset($wobd_common_settings['wobd_page_configure_option']) && $wobd_common_settings['wobd_page_configure_option'] == 'method_two') {
                add_action('woocommerce_before_single_product_summary', array($this, 'wobd_display_single_page_badges'), 20);
                add_filter('woocommerce_sale_flash', array($this, 'wobd_remove_sale_text'), 2, 2);
            } else if (isset($wobd_common_settings['wobd_page_configure_option']) && $wobd_common_settings['wobd_page_configure_option'] == 'method_three') {
                add_filter('woocommerce_sale_flash', array($this, 'wobd_custom_sale_text'), 10, 3);
            } else {
                add_action( 'woocommerce_before_single_product_summary', array( $this, 'wobd_old_display_single_page_badges' ), 10 );
                add_action( 'woocommerce_before_shop_loop_item_title', array( $this, 'wobd_badge_wrapper_start' ), 5, 2 );
                add_action( 'woocommerce_before_shop_loop_item_title', array( $this, 'wobd_old_display_product_badges_action' ) );
                add_action( 'woocommerce_before_shop_loop_item_title', array( $this, 'wobd_badge_wrapper_close' ), 12, 2 );
            }
            if (isset($wobd_common_settings['wobd_shop_configure_option']) && $wobd_common_settings['wobd_shop_configure_option'] == 'method_one') {
                add_filter('post_thumbnail_html', array($this, 'wobd_badge_on_product'), 999, 1);
                add_filter('woocommerce_product_get_image', array($this, 'wobd_badge_on_product'), 999, 1);
                add_filter('woocommerce_sale_flash', array($this, 'wobd_remove_sale_text'), 2, 2);
            } else if (isset($wobd_common_settings['wobd_shop_configure_option']) && $wobd_common_settings['wobd_shop_configure_option'] == 'method_two') {
                add_action('woocommerce_before_shop_loop_item_title', array($this, 'wobd_badge_wrapper_start'), 5, 2);
                add_action('woocommerce_before_shop_loop_item_title', array($this, 'wobd_display_product_badges_action'));
                add_action('woocommerce_before_shop_loop_item_title', array($this, 'wobd_badge_wrapper_close'), 12, 2);
                add_filter('woocommerce_sale_flash', array($this, 'wobd_remove_sale_text'), 2, 2);
            } else {
                add_filter('woocommerce_sale_flash', array($this, 'wobd_custom_sale_text'), 10, 3);
            }
            add_filter('woocommerce_locate_template', array($this, 'wobd_locate_template'), 20, 3);
        }

        function wobd_change_publish_button($translation, $text) {
            if ('wobd-badge-designer' == get_post_type())
                if ($text == 'Publish' || $text == 'Update')
                    return 'Save';
                return $translation;
            }

            function wobd_hide_publishing_actions() {
                $my_post_type = 'wobd-badge-designer';
                global $post;
                if ($post->post_type == $my_post_type) {
                    echo '
                    <style type="text/css">
                    #misc-publishing-actions,
                    #minor-publishing-actions{
                    display:none;
                }
                    #view-post-btn, .updated a,#screen-meta-links .screen-meta-toggle
                {
                    display: none;
                }
                </style>
                ';
            }
        }

        function wobd_add_badges_setup() {
            add_meta_box('wobd_add_badges', __('Woo Badge Designer', WOBD_TD), array($this, 'wobd_add_action'), 'wobd-badge-designer', 'normal', 'low');
        }

        function wobd_add_action($post) {
            wp_nonce_field(basename(__FILE__), 'wobd_badge_nonce');
            include(WOBD_PATH . 'includes/admin/view/wobd-add-setting.php');
        }

        function wobd_badge_preview() {
            add_meta_box('wobd_preview_badges', __('Badge Preview', WOBD_TD), array($this, 'wobd_preview_action'), 'wobd-badge-designer', 'side', 'default');
        }

        function wobd_preview_action($post) {
            wp_nonce_field(basename(__FILE__), 'wobd_badge_nonce');
            include(WOBD_PATH . 'includes/admin/view/wobd-preview.php');
        }

        function wobd_individual_badge_settings() {
            add_meta_box('wobd_each_badges_settings', __('Woo Badge Designer Setting', WOBD_TD), array($this, 'wobd_each_badge_action'), 'product', 'normal', 'low');
        }

        function wobd_each_badge_action($post) {
            wp_nonce_field(basename(__FILE__), 'wobd_badge_nonce');
            include(WOBD_PATH . 'includes/admin/view/wobd-each-badges.php');
        }

        function wobd_remove_row_actions($actions) {
            if (get_post_type() == 'wobd-badge-designer') { // choose the post type where you want to hide the button
                unset($actions['view']); // this hides the VIEW button on your edit post screen
                unset($actions['inline hide-if-no-js']);
            }
            return $actions;
        }

        /* Add custom column to post list */

        function wobd_columns_head($columns) {
            unset($columns['date']);
            $columns['badge_type'] = __('Badge Type', WOBD_TD);
            $columns['badge_text_letter'] = __('Badges', WOBD_TD);
            $columns['badge_date'] = __('Date', WOBD_TD);
            return $columns;
        }

        function wobd_columns_content($column, $post_id) {
            $id = $post_id;
            $wobd_option = get_post_meta($post_id, 'wobd_option', true);
            if ($column == 'badge_type') {
                if (isset($wobd_option['background_type']) && $wobd_option['background_type'] == 'text-background') {
                    $value = $wobd_option['text_design_templates'];
                    $template = explode('-', $value);
                    ?>
                    <img class="wobd-live-image" src="<?php echo WOBD_IMG_DIR . 'text-design/' . $template[1] . '.png' ?>">
                    <?php
                } else {
                    ?>
                    <img class="wobd-live-image" src="<?php echo WOBD_IMG_DIR . 'badges/' . $wobd_option['existing_image'] . '.png' ?>">
                    <?php
                }
            }
            if ($column == 'badge_text_letter') {

                if (isset($wobd_option['badge_type']) && $wobd_option['badge_type'] == 'text') {
                    echo $wobd_option['badge_text'];
                }
            }
            if ($column == 'badge_date') {
                echo get_the_date('l, F j, Y', $post_id) . "<br>" . get_post_status($post_id);
            }
        }

        function wobd_display_single_page_badges() {
            global $woocommerce;
            global $product;
            $wobd_common_settings = get_option('wobd_common_settings');
            $wobd_low_stock_qty = isset( $wobd_common_settings['wobd_low_stock_qty'] ) ? esc_attr( $wobd_common_settings['wobd_low_stock_qty'] ) : '3';
            //  $product = new WC_Product( get_the_ID() );
            $wobd_common_settings = get_option('wobd_common_settings');
            if (isset($wobd_common_settings['wobd_enable_single_page_badge']) && $wobd_common_settings['wobd_enable_single_page_badge'] == '1') {
                include(WOBD_PATH . 'includes/frontend/badges.php');
                if ($wobd_common_settings['wobd_default_sale_badge'] != 'disable' && $wobd_common_settings['wobd_default_sale_badge'] != 'default') {
                    if ($product->is_on_sale() && $product->is_in_stock()) {
                        $wobd_post_id = $wobd_common_settings['wobd_default_sale_badge'];
                        $wobd_option = get_post_meta($wobd_post_id, 'wobd_option', true);
                        include(WOBD_PATH . 'includes/frontend/template/sales/sales-content.php');
                    }
                }
                if (isset($wobd_common_settings['wobd_stock_badge']) && $wobd_common_settings['wobd_stock_badge'] != 'default') {
                    if (!$product->is_in_stock()) {
                        remove_action('woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10);
                        $wobd_stock_id = $wobd_common_settings['wobd_stock_badge'];
                        $wobd_option = get_post_meta($wobd_stock_id, 'wobd_option', true);
                        include(WOBD_PATH . 'includes/frontend/badge-content.php');
                    }
                }
                if ($wobd_common_settings['wobd_default_featured_badge'] != 'disable' && $wobd_common_settings['wobd_default_featured_badge'] != 'default') {
                    if ($product->is_featured() && $product->is_in_stock() && !$product->is_on_sale()) {
                        $wobd_post_id = $wobd_common_settings['wobd_default_featured_badge'];
                        $wobd_option = get_post_meta($wobd_post_id, 'wobd_option', true);
                        include(WOBD_PATH . 'includes/frontend/template/sales/sales-content.php');
                    }
                }
                if ($wobd_common_settings['wobd_default_downloadable_badge'] != 'disable' && $wobd_common_settings['wobd_default_downloadable_badge'] != 'default') {
                    if ($product->is_downloadable() && !$product->is_on_sale()) {
                        $wobd_post_id = $wobd_common_settings['wobd_default_downloadable_badge'];
                        $wobd_option = get_post_meta($wobd_post_id, 'wobd_option', true);
                        include(WOBD_PATH . 'includes/frontend/template/sales/sales-content.php');
                    }
                }
                if (isset($wobd_common_settings['wobd_default_lowstock_badge']) && $wobd_common_settings['wobd_default_lowstock_badge'] != 'disable') {
                    if ($product->is_in_stock() && $product->get_stock_quantity() <= $wobd_low_stock_qty) {
                        remove_action('woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10);
                        $wobd_stock_id = $wobd_common_settings['wobd_default_lowstock_badge'];
                        $wobd_option = get_post_meta($wobd_stock_id, 'wobd_option', true);
                        include(WOBD_PATH . 'includes/frontend/badge-content.php');
                    }
                }
                if (isset($wobd_common_settings['wobd_default_recent_badge']) && $wobd_common_settings['wobd_default_recent_badge'] != 'disable') {
                    $wobd_common_settings = get_option('wobd_common_settings');
                    $freshness = isset( $wobd_common_settings['wobd_recent_days'] ) ? esc_attr( $wobd_common_settings['wobd_recent_days'] ) : '1';
                    $postdate      = get_the_time( 'Y-m-d', $product_id );
                    $postdatestamp = strtotime( $postdate );
                    if ( ( time() - ( 60 * 60 * 24 * $freshness ) ) < $postdatestamp ) {
                        $wobd_post_id = $wobd_common_settings['wobd_default_recent_badge'];
                        $wobd_option = get_post_meta($wobd_post_id, 'wobd_option', true);
                        include(WOBD_PATH . 'includes/frontend/badge-content.php');
                    }
                }
                if (isset($wobd_common_settings['wobd_default_backorder_badge']) && $wobd_common_settings['wobd_default_backorder_badge'] != 'default') {
                    if ($product->is_on_backorder()) {
                        remove_action('woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10);
                        $wobd_stock_id = $wobd_common_settings['wobd_default_backorder_badge'];
                        $wobd_option = get_post_meta($wobd_stock_id, 'wobd_option', true);
                        include(WOBD_PATH . 'includes/frontend/badge-content.php');
                    }
                }
            }
        }

        /**
         * Add form value in database
         *
         * @since 1.0.1
         * */
        function wobd_form_settings() {
            if (isset($_POST['wobd_form_nonce_field']) && wp_verify_nonce($_POST['wobd_form_nonce_field'], 'wobd_form_nonce')) {

                if (isset($_POST['wobd_common_settings'])) {
                    $wobd_common = (array) $_POST['wobd_common_settings'];
// sanitize array
                    $wobd_common_option = array_map('sanitize_text_field', $wobd_common);
// save data
                    update_option('wobd_common_settings', $wobd_common_option);
                }
            }
            wp_redirect(admin_url('admin.php?page=wobd-badges-settings&message=1'));
            exit;
        }

        function wobd_custom_sale_text($text, $flash) {
            $wobd_common_settings = get_option('wobd_common_settings');
            global $post;
            global $product;
            $product = new WC_Product(get_the_ID());
            $wobd_common_settings = get_option('wobd_common_settings');
            $wobd_low_stock_qty = isset( $wobd_common_settings['wobd_low_stock_qty'] ) ? esc_attr( $wobd_common_settings['wobd_low_stock_qty'] ) : '3';
            if (is_product()) {
                if ((isset($wobd_common_settings['wobd_default_sale_badge'])) && ($wobd_common_settings['wobd_default_sale_badge'] == 'disable')) {
                    $text = '';
                    return $text;
                } else if ( (isset($wobd_common_settings['wobd_default_sale_badge'])) && ($wobd_common_settings['wobd_default_sale_badge'] == 'default')) {
                    return $text;
                } else {
                    ob_start();
                    if (isset($wobd_common_settings['wobd_enable_single_page_badge']) && $wobd_common_settings['wobd_enable_single_page_badge'] == '1') {
                        include(WOBD_PATH . 'includes/frontend/badges.php');
                        if ($wobd_common_settings['wobd_default_sale_badge'] != 'disable' && $wobd_common_settings['wobd_default_sale_badge'] != 'default') {
                            if ($product->is_on_sale() && $product->is_in_stock()) {
                                $wobd_post_id = $wobd_common_settings['wobd_default_sale_badge'];
                                $wobd_option = get_post_meta($wobd_post_id, 'wobd_option', true);
                                include(WOBD_PATH . 'includes/frontend/template/sales/sales-content.php');
                            }
                        }
                        if (isset($wobd_common_settings['wobd_stock_badge']) && $wobd_common_settings['wobd_stock_badge'] != 'default') {
                            if (!$product->is_in_stock()) {
                                $wobd_stock_id = $wobd_common_settings['wobd_stock_badge'];
                                $wobd_option = get_post_meta($wobd_stock_id, 'wobd_option', true);
                                include(WOBD_PATH . 'includes/frontend/badge-content.php');
                            }
                        }
                        if ($wobd_common_settings['wobd_default_featured_badge'] != 'disable' && $wobd_common_settings['wobd_default_featured_badge'] != 'default') {
                            if ($product->is_featured() && $product->is_in_stock() && !$product->is_on_sale()) {
                                $wobd_post_id = $wobd_common_settings['wobd_default_featured_badge'];
                                $wobd_option = get_post_meta($wobd_post_id, 'wobd_option', true);
                                include(WOBD_PATH . 'includes/frontend/template/sales/sales-content.php');
                            }
                        }
                        if ($wobd_common_settings['wobd_default_downloadable_badge'] != 'disable' && $wobd_common_settings['wobd_default_downloadable_badge'] != 'default') {
                    if ($product->is_downloadable() && !$product->is_on_sale()) {
                        $wobd_post_id = $wobd_common_settings['wobd_default_downloadable_badge'];
                        $wobd_option = get_post_meta($wobd_post_id, 'wobd_option', true);
                        include(WOBD_PATH . 'includes/frontend/template/sales/sales-content.php');
                    }
                }
                        if (isset($wobd_common_settings['wobd_default_lowstock_badge']) && $wobd_common_settings['wobd_default_lowstock_badge'] != 'default') {
                    if ($product->is_in_stock() && $product->get_stock_quantity() <= $wobd_low_stock_qty) {
                        remove_action('woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10);
                        $wobd_stock_id = $wobd_common_settings['wobd_default_lowstock_badge'];
                        $wobd_option = get_post_meta($wobd_stock_id, 'wobd_option', true);
                        include(WOBD_PATH . 'includes/frontend/badge-content.php');
                    }
                }
                if (isset($wobd_common_settings['wobd_default_recent_badge']) && $wobd_common_settings['wobd_default_recent_badge'] != 'disable') {
                $wobd_common_settings = get_option('wobd_common_settings');
                $freshness = isset( $wobd_common_settings['wobd_recent_days'] ) ? esc_attr( $wobd_common_settings['wobd_recent_days'] ) : '1';
                $postdate      = get_the_time( 'Y-m-d', $product_id );
            $postdatestamp = strtotime( $postdate );
            if ( ( time() - ( 60 * 60 * 24 * $freshness ) ) < $postdatestamp ) {
                        remove_action('woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10);
                        $wobd_stock_id = $wobd_common_settings['wobd_default_recent_badge'];
                        $wobd_option = get_post_meta($wobd_stock_id, 'wobd_option', true);
                        include(WOBD_PATH . 'includes/frontend/badge-content.php');
                    }
            }
            if (isset($wobd_common_settings['wobd_default_backorder_badge']) && $wobd_common_settings['wobd_default_backorder_badge'] != 'default') {
                            if ($product->is_on_backorder()) {
                                $wobd_stock_id = $wobd_common_settings['wobd_default_backorder_badge'];
                                $wobd_option = get_post_meta($wobd_stock_id, 'wobd_option', true);
                                include(WOBD_PATH . 'includes/frontend/badge-content.php');
                            }
                        }
                    }
                    $data = ob_get_contents();
                    $text = '<div class="wobd-badges-wrapper">' . $data . '</div>';
                    ob_end_clean();

                    return $text;
                }
            } else {
                if ((isset($wobd_common_settings['wobd_default_sale_badge'])) && ($wobd_common_settings['wobd_default_sale_badge'] == 'disable')) {
                    $text = '';
                    return $text;
                } else if ( (isset($wobd_common_settings['wobd_default_sale_badge'])) && ($wobd_common_settings['wobd_default_sale_badge'] == 'default')) {
                    return $text;
                } else {
                    ob_start();
                    include(WOBD_PATH . 'includes/frontend/badges.php');
                    if ($product->is_on_sale() && $product->is_in_stock()) {
                        $sale_badge = isset($wobd_common_settings['wobd_default_sale_badge']) ? esc_attr($wobd_common_settings['wobd_default_sale_badge']) : 'disable';
                        if (($sale_badge != 'disable') && ($sale_badge != 'default')) {
                            $wobd_post_id = $wobd_common_settings['wobd_default_sale_badge'];
                            $wobd_option = get_post_meta($wobd_post_id, 'wobd_option', true);
                            include(WOBD_PATH . 'includes/frontend/template/sales/sales-content.php');
                        }
                    }
                    if (isset($wobd_common_settings['wobd_stock_badge']) && $wobd_common_settings['wobd_stock_badge'] != 'default') {
                        if (!$product->is_in_stock()) {
                            $wobd_stock_id = $wobd_common_settings['wobd_stock_badge'];
                            $wobd_option = get_post_meta($wobd_stock_id, 'wobd_option', true);
                            include(WOBD_PATH . 'includes/frontend/badge-content.php');
                        }
                    }
                    if ($product->is_featured() && $product->is_in_stock() && !$product->is_on_sale()) {
                        $sale_badge = isset($wobd_common_settings['wobd_default_featured_badge']) ? esc_attr($wobd_common_settings['wobd_default_featured_badge']) : 'disable';
                        if (($sale_badge != 'disable') && ($sale_badge != 'default')) {
                            $wobd_post_id = $wobd_common_settings['wobd_default_featured_badge'];
                            $wobd_option = get_post_meta($wobd_post_id, 'wobd_option', true);
                            include(WOBD_PATH . 'includes/frontend/template/sales/sales-content.php');
                        }
                    }
                    if ($wobd_common_settings['wobd_default_downloadable_badge'] != 'disable' && $wobd_common_settings['wobd_default_downloadable_badge'] != 'default') {
                    if ($product->is_downloadable() && !$product->is_on_sale()) {
                        $wobd_post_id = $wobd_common_settings['wobd_default_downloadable_badge'];
                        $wobd_option = get_post_meta($wobd_post_id, 'wobd_option', true);
                        include(WOBD_PATH . 'includes/frontend/template/sales/sales-content.php');
                    }
                }
                    if (isset($wobd_common_settings['wobd_default_lowstock_badge']) && $wobd_common_settings['wobd_default_lowstock_badge'] != 'disable') {
                        $wobd_common_settings = get_option('wobd_common_settings');
            $wobd_low_stock_qty = isset( $wobd_common_settings['wobd_low_stock_qty'] ) ? esc_attr( $wobd_common_settings['wobd_low_stock_qty'] ) : '3';
                    if ($product->is_in_stock() && $product->get_stock_quantity() <= $wobd_low_stock_qty) {
                        remove_action('woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10);
                        $wobd_stock_id = $wobd_common_settings['wobd_default_lowstock_badge'];
                        $wobd_option = get_post_meta($wobd_stock_id, 'wobd_option', true);
                        include(WOBD_PATH . 'includes/frontend/badge-content.php');
                    }
                }
                if (isset($wobd_common_settings['wobd_default_recent_badge']) && $wobd_common_settings['wobd_default_recent_badge'] != 'disable') {
                $wobd_common_settings = get_option('wobd_common_settings');
                $freshness = isset( $wobd_common_settings['wobd_recent_days'] ) ? esc_attr( $wobd_common_settings['wobd_recent_days'] ) : '1';
                $postdate      = get_the_time( 'Y-m-d', $product_id );
            $postdatestamp = strtotime( $postdate );
            if ( ( time() - ( 60 * 60 * 24 * $freshness ) ) < $postdatestamp ) {
                        remove_action('woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10);
                        $wobd_stock_id = $wobd_common_settings['wobd_default_recent_badge'];
                        $wobd_option = get_post_meta($wobd_stock_id, 'wobd_option', true);
                        include(WOBD_PATH . 'includes/frontend/badge-content.php');
                    }
            }
            if (isset($wobd_common_settings['wobd_default_backorder_badge']) && $wobd_common_settings['wobd_default_backorder_badge'] != 'default') {
                        if ($product->is_on_backorder()) {
                            $wobd_stock_id = $wobd_common_settings['wobd_default_backorder_badge'];
                            $wobd_option = get_post_meta($wobd_stock_id, 'wobd_option', true);
                            include(WOBD_PATH . 'includes/frontend/badge-content.php');
                        }
                    }
                    $data = ob_get_contents();
                    if (is_admin()) {
                        $html = $text;
                    } else {
                        if (is_cart() || is_checkout() || is_account_page() || is_wc_endpoint_url()) {
                            $html = $text;
                        } else {
                            $html = '<div class="wobd-badges-wrapper">' . $data . '</div>';
                        }
                    }
                    ob_end_clean();
                }
                return $html;
            }
        }

        function wobd_badge_on_product($html) {
            global $post;
            global $product;
            $wobd_common_settings = get_option('wobd_common_settings');
            $wobd_low_stock_qty = isset( $wobd_common_settings['wobd_low_stock_qty'] ) ? esc_attr( $wobd_common_settings['wobd_low_stock_qty'] ) : '3';
            if ($product) {
                /*if(get_post_type(get_the_ID())=='product'){
                    $product = new WC_Product(get_the_ID());*/
                    ob_start();
                    $wobd_common_settings = get_option('wobd_common_settings');
                    include(WOBD_PATH . 'includes/frontend/badges.php');
                    if ($product->is_on_sale() && $product->is_in_stock()) {
                        remove_action('woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10);
                        $sale_badge = isset($wobd_common_settings['wobd_default_sale_badge']) ? esc_attr($wobd_common_settings['wobd_default_sale_badge']) : 'disable';
                        if (($sale_badge != 'disable') && ($sale_badge != 'default')) {
                            $wobd_post_id = $wobd_common_settings['wobd_default_sale_badge'];
                            $wobd_option = get_post_meta($wobd_post_id, 'wobd_option', true);
                            include(WOBD_PATH . 'includes/frontend/template/sales/sales-content.php');
                        }
                    }
                    if (isset($wobd_common_settings['wobd_stock_badge']) && $wobd_common_settings['wobd_stock_badge'] != 'default') {
                        if (!$product->is_in_stock()) {
                            remove_action('woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10);
                            $wobd_stock_id = $wobd_common_settings['wobd_stock_badge'];
                            $wobd_option = get_post_meta($wobd_stock_id, 'wobd_option', true);
                            include(WOBD_PATH . 'includes/frontend/badge-content.php');
                        }
                    }
                    if ($product->is_featured() && $product->is_in_stock() && !$product->is_on_sale()) {
                        remove_action('woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10);
                        $sale_badge = isset($wobd_common_settings['wobd_default_featured_badge']) ? esc_attr($wobd_common_settings['wobd_default_featured_badge']) : 'disable';
                        if (($sale_badge != 'disable') && ($sale_badge != 'default')) {
                            $wobd_post_id = $wobd_common_settings['wobd_default_featured_badge'];
                            $wobd_option = get_post_meta($wobd_post_id, 'wobd_option', true);
                            include(WOBD_PATH . 'includes/frontend/template/sales/sales-content.php');
                        }
                    }
                    if ($wobd_common_settings['wobd_default_downloadable_badge'] != 'disable' && $wobd_common_settings['wobd_default_downloadable_badge'] != 'default') {
                    if ($product->is_downloadable() && !$product->is_on_sale()) {
                        $wobd_post_id = $wobd_common_settings['wobd_default_downloadable_badge'];
                        $wobd_option = get_post_meta($wobd_post_id, 'wobd_option', true);
                        include(WOBD_PATH . 'includes/frontend/template/sales/sales-content.php');
                    }
                }
                    if (isset($wobd_common_settings['wobd_default_lowstock_badge']) && $wobd_common_settings['wobd_default_lowstock_badge'] != 'disable') {
                    if ($product->is_in_stock() && $product->get_stock_quantity() <= $wobd_low_stock_qty) {
                        remove_action('woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10);
                        $wobd_stock_id = $wobd_common_settings['wobd_default_lowstock_badge'];
                        $wobd_option = get_post_meta($wobd_stock_id, 'wobd_option', true);
                        include(WOBD_PATH . 'includes/frontend/badge-content.php');
                    }
                }
                if (isset($wobd_common_settings['wobd_default_recent_badge']) && $wobd_common_settings['wobd_default_recent_badge'] != 'disable') {
                $wobd_common_settings = get_option('wobd_common_settings');
                $freshness = isset( $wobd_common_settings['wobd_recent_days'] ) ? esc_attr( $wobd_common_settings['wobd_recent_days'] ) : '1';
                $postdate      = get_the_time( 'Y-m-d', $product_id );
            $postdatestamp = strtotime( $postdate );
            if ( ( time() - ( 60 * 60 * 24 * $freshness ) ) < $postdatestamp ) {
                        remove_action('woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10);
                        $wobd_stock_id = $wobd_common_settings['wobd_default_recent_badge'];
                        $wobd_option = get_post_meta($wobd_stock_id, 'wobd_option', true);
                        include(WOBD_PATH . 'includes/frontend/badge-content.php');
                    }
            }
            if (isset($wobd_common_settings['wobd_default_backorder_badge']) && $wobd_common_settings['wobd_default_backorder_badge'] != 'default') {
                        if ($product->is_on_backorder()) {
                            remove_action('woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10);
                            $wobd_stock_id = $wobd_common_settings['wobd_default_backorder_badge'];
                            $wobd_option = get_post_meta($wobd_stock_id, 'wobd_option', true);
                            include(WOBD_PATH . 'includes/frontend/badge-content.php');
                        }
                    }
                    $data = ob_get_contents();
                    if (is_admin()) {
                        $html = $html;
                    } else {
                        if (is_cart() || is_checkout() || is_account_page() || is_wc_endpoint_url() || is_product()) {
                            $html = $html;
                        } else {
                            $html = '<div class="wobd-badges-wrapper">' . $data . $html . '</div>';
                        }
                    }
                    ob_end_clean();
            }
            return $html;
        }

        // Add the opening div to the img
        function wobd_badge_wrapper_start() {

            echo '<div class="wobd-badges-wrapper">';
        }

        // Close the div that we just added
        function wobd_badge_wrapper_close() {
            echo '</div>';
        }

        function wobd_display_product_badges_action() {
            global $product;
            $wobd_common_settings = get_option('wobd_common_settings');
            $wobd_low_stock_qty = isset( $wobd_common_settings['wobd_low_stock_qty'] ) ? esc_attr( $wobd_common_settings['wobd_low_stock_qty'] ) : '3';
            $wobd_common_settings = get_option('wobd_common_settings');
            include(WOBD_PATH . 'includes/frontend/badges.php');
            if ($product->is_on_sale() && $product->is_in_stock()) {
                remove_action('woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10);
                $sale_badge = isset($wobd_common_settings['wobd_default_sale_badge']) ? esc_attr($wobd_common_settings['wobd_default_sale_badge']) : 'disable';
                if (($sale_badge != 'disable') && ($sale_badge != 'default')) {
                    $wobd_post_id = $wobd_common_settings['wobd_default_sale_badge'];
                    $wobd_option = get_post_meta($wobd_post_id, 'wobd_option', true);
                    include(WOBD_PATH . 'includes/frontend/template/sales/sales-content.php');
                }
            }
            if (isset($wobd_common_settings['wobd_stock_badge']) && $wobd_common_settings['wobd_stock_badge'] != 'default') {
                if (!$product->is_in_stock()) {
                    remove_action('woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10);
                    $wobd_stock_id = $wobd_common_settings['wobd_stock_badge'];
                    $wobd_option = get_post_meta($wobd_stock_id, 'wobd_option', true);
                    include(WOBD_PATH . 'includes/frontend/badge-content.php');
                }
            }
            if ($product->is_featured() && $product->is_in_stock() && !$product->is_on_sale()) {
                remove_action('woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10);
                $sale_badge = isset($wobd_common_settings['wobd_default_featured_badge']) ? esc_attr($wobd_common_settings['wobd_default_featured_badge']) : 'disable';
                if (($sale_badge != 'disable') && ($sale_badge != 'default')) {
                    $wobd_post_id = $wobd_common_settings['wobd_default_featured_badge'];
                    $wobd_option = get_post_meta($wobd_post_id, 'wobd_option', true);
                    include(WOBD_PATH . 'includes/frontend/template/sales/sales-content.php');
                }
            }
            if ($wobd_common_settings['wobd_default_downloadable_badge'] != 'disable' && $wobd_common_settings['wobd_default_downloadable_badge'] != 'default') {
                    if ($product->is_downloadable() && !$product->is_on_sale()) {
                        $wobd_post_id = $wobd_common_settings['wobd_default_downloadable_badge'];
                        $wobd_option = get_post_meta($wobd_post_id, 'wobd_option', true);
                        include(WOBD_PATH . 'includes/frontend/template/sales/sales-content.php');
                    }
                }
            if (isset($wobd_common_settings['wobd_default_lowstock_badge']) && $wobd_common_settings['wobd_default_lowstock_badge'] != 'default') {
                    if ($product->is_in_stock() && $product->get_stock_quantity() <= $wobd_low_stock_qty) {
                        remove_action('woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10);
                        $wobd_stock_id = $wobd_common_settings['wobd_default_lowstock_badge'];
                        $wobd_option = get_post_meta($wobd_stock_id, 'wobd_option', true);
                        include(WOBD_PATH . 'includes/frontend/badge-content.php');
                    }
            }
            if (isset($wobd_common_settings['wobd_default_recent_badge']) && $wobd_common_settings['wobd_default_recent_badge'] != 'default') {
                $wobd_common_settings = get_option('wobd_common_settings');
                $freshness = isset( $wobd_common_settings['wobd_recent_days'] ) ? esc_attr( $wobd_common_settings['wobd_recent_days'] ) : '1';
                $postdate      = get_the_time( 'Y-m-d', $product_id );
            $postdatestamp = strtotime( $postdate );
            if ( ( time() - ( 60 * 60 * 24 * $freshness ) ) < $postdatestamp ) {
                        remove_action('woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10);
                        $wobd_stock_id = $wobd_common_settings['wobd_default_recent_badge'];
                        $wobd_option = get_post_meta($wobd_stock_id, 'wobd_option', true);
                        include(WOBD_PATH . 'includes/frontend/badge-content.php');
                    }
            }
            if (isset($wobd_common_settings['wobd_default_backorder_badge']) && $wobd_common_settings['wobd_default_backorder_badge'] != 'default') {
                if ($product->is_on_backorder()) {
                    remove_action('woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10);
                    $wobd_stock_id = $wobd_common_settings['wobd_default_backorder_badge'];
                    $wobd_option = get_post_meta($wobd_stock_id, 'wobd_option', true);
                    include(WOBD_PATH . 'includes/frontend/badge-content.php');
                }
            }
        }

        function wobd_remove_sale_text($text, $flash) {
            $wobd_common_settings = get_option('wobd_common_settings');
            if ($wobd_common_settings['wobd_default_sale_badge'] == 'disable') {
                $text = '';
                return $text;
            } else if ($wobd_common_settings['wobd_default_sale_badge'] == 'default') {
                return $text;
            }
        }

        function wobd_locate_template($template, $template_name, $template_path) {
            if ($template_name == 'loop/sale-flash.php') {
                $template = WOBD_PATH . '/woocommerce/templates/loop/sale-flash.php';
            }
            if ($template_name == 'single-product/sale-flash.php') {
                $template = WOBD_PATH . '/woocommerce/templates/single-product/sale-flash.php';
            }
            return $template;
        }

        function wobd_old_display_single_page_badges(){
            global $product;
            remove_action( 'woocommerce_before_single_product_summary', 'woocommerce_show_product_images', 20 );
            include(WOBD_PATH . 'includes/frontend/template/single-product.php');
        }

        function wobd_old_display_product_badges_action(){
            include(WOBD_PATH . 'includes/frontend/badges.php');
            $wobd_common_settings = get_option( 'wobd_common_settings' );
            if ( isset( $wobd_common_settings[ 'wobd_stock_badge' ] ) && $wobd_common_settings[ 'wobd_stock_badge' ] != 'disable' ) {
                global $product;
                if ( ! $product->is_in_stock() ) {
                    $wobd_stock_id = $wobd_common_settings[ 'wobd_stock_badge' ];
                    $wobd_option = get_post_meta( $wobd_stock_id, 'wobd_option', true );
                    include(WOBD_PATH . 'includes/frontend/badge-content.php');
                }

            }
        }

    }

    new WOBD_Setup();
}